package App::ExecIf;

our $VERSION = '0.02'; # VERSION

1;
# ABSTRACT: Execute command on some condition

__END__

=pod

=encoding UTF-8

=head1 NAME

App::ExecIf - Execute command on some condition

=head1 VERSION

This document describes version 0.02 of App::ExecIf (from Perl distribution App-ExecIf), released on 2017-07-04.

=head1 SYNOPSIS

This distribution provides some command-line utilities:

 exec-if-env
 exec-if-not-env

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-ExecIf>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-App-ExecIf>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ExecIf>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017, 2013 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
